From 757780541681ab66af181b0d798a5b294e8613dd Mon Sep 17 00:00:00 2001
From: Kedar Sovani <kedars@marvell.com>
Date: Wed, 7 Jan 2009 15:54:02 +0530
Subject: [PATCH] kernel: only build kernel-headers on ARM

Since kernels for different ARM CPUs differ wildly, and since
embedded folks tend to provide their own kernels, this patch makes
the Fedora kernel package only build kernel-headers when built for
ARM.

Signed-off-by: Lennert Buytenhek <buytenh@marvell.com>
Signed-off-by: Kedar Sovani <kedars@marvell.com>
---
 Makefile.config |    5 ++++-
 config-arm      |   15 +++++++++++++++
 kernel.spec     |   16 +++++++++++++---
 3 files changed, 32 insertions(+), 4 deletions(-)
 create mode 100644 config-arm

diff --git a/Makefile.config b/Makefile.config
index 09adc2e..bc1420a 100644
--- a/Makefile.config
+++ b/Makefile.config
@@ -9,7 +9,7 @@ CONFIGFILES	= \
 	$(CFG)-i686.config $(CFG)-i686-PAE.config \
 	$(CFG)-i686-debug.config $(CFG)-i686-PAEdebug.config \
 	$(CFG)-x86_64.config $(CFG)-x86_64-debug.config \
-	$(CFG)-s390x.config \
+	$(CFG)-s390x.config $(CFG)-arm.config \
 	$(CFG)-ppc.config $(CFG)-ppc-smp.config \
 	$(CFG)-sparc64.config $(CFG)-sparc64-smp.config \
 	$(CFG)-ppc64.config $(CFG)-ppc64-kdump.config $(CFG)-ppc64-debug.config \
@@ -102,6 +102,9 @@ kernel-$(VERSION)-ppc64-debug.config: config-powerpc64 temp-powerpc-debug-generi
 kernel-$(VERSION)-s390x.config: config-s390x temp-s390-generic
 	perl merge.pl $^ s390 > $@
 
+kernel-$(VERSION)-arm.config: config-arm temp-generic
+	perl merge.pl $^ arm > $@
+
 kernel-$(VERSION)-ppc.config: /dev/null temp-powerpc32-generic
 	perl merge.pl $^ powerpc > $@
 
diff --git a/config-arm b/config-arm
new file mode 100644
index 0000000..692f205
--- /dev/null
+++ b/config-arm
@@ -0,0 +1,15 @@
+CONFIG_ARM=y
+CONFIG_SYS_SUPPORTS_APM_EMULATION=y
+# CONFIG_SMP is not set
+
+CONFIG_CC_OPTIMIZE_FOR_SIZE=y
+
+CONFIG_ARCH_VERSATILE=y
+
+CONFIG_ARM_THUMB=y
+
+CONFIG_AEABI=y
+CONFIG_OABI_COMPAT=y
+
+CONFIG_CMDLINE="console=ttyAM0,115200 root=/dev/sda1 rootdelay=20"
+
diff --git a/kernel.spec b/kernel.spec
index bb4be88..ee3e300 100644
--- a/kernel.spec
+++ b/kernel.spec
@@ -342,6 +342,14 @@ Summary: The Linux kernel
 %define kernel_image vmlinux
 %endif
 
+%ifarch %{arm}
+%define all_arch_configs kernel-%{version}-arm*.config
+%define image_install_path boot
+%define hdrarch arm
+%define make_target vmlinux
+%define kernel_image vmlinux
+%endif
+
 %if %{nopatches}
 # XXX temporary until last vdso patches are upstream
 %define vdso_arches ppc ppc64
@@ -363,7 +371,7 @@ Summary: The Linux kernel
 
 # We don't build a kernel on i386; we only do kernel-headers there,
 # and we no longer build for 31bit S390. Same for 32bit sparc.
-%define nobuildarches i386 s390 sparc
+%define nobuildarches i386 s390 sparc %{arm}
 
 %ifarch %nobuildarches
 %define with_up 0
@@ -455,10 +463,10 @@ Group: System Environment/Kernel
 License: GPLv2
 URL: http://www.kernel.org/
 Version: %{rpmversion}
-Release: %{pkg_release}
+Release: %{pkg_release}.fa1
 # DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
 # SET %%nobuildarches (ABOVE) INSTEAD
-ExclusiveArch: noarch %{all_x86} x86_64 ppc ppc64 ia64 sparc sparc64 s390x alpha alphaev56
+ExclusiveArch: noarch %{all_x86} x86_64 ppc ppc64 ia64 sparc sparc64 s390x alpha alphaev56 %{arm}
 ExclusiveOS: Linux
 
 %kernel_reqprovconf
@@ -557,6 +565,8 @@ Patch00: patch-2.6.%{base_sublevel}-git%{gitrev}.bz2
 %endif
 %endif
 
+Source100: config-arm
+
 %if %{using_upstream_branch}
 ### BRANCH PATCH ###
 %endif
-- 
1.5.3.3

